#!/usr/bin/env python
# Generated by jaraco.develop (https://bitbucket.org/jaraco/jaraco.develop)
import os

from setuptools import find_packages

with open(os.path.join(os.path.dirname(__file__), 'README')) as readme:
	long_description = readme.read()

setup_params = dict(
	name='jaraco.modb',
	description="MongoDB Object DataBase (MODB) for Python objects",
	long_description=long_description,
	use_hg_version=dict(increment='0.1'),
	packages=find_packages(),
	namespace_packages=['jaraco'],
	zip_safe=False,
	classifiers = [
		"Development Status :: 5 - Production/Stable",
		"Intended Audience :: Developers",
		"Programming Language :: Python :: 2.6",
		"Programming Language :: Python :: 2.7",
		"Programming Language :: Python :: 3",
	],
	install_requires=[
		'jsonpickle==0.4.0',
		'pymongo',
		'jaraco.util',
	],
	setup_requires=[
		'hgtools<8',
		'pytest-runner',
	],
)
if __name__ == '__main__':
	from setuptools import setup
	setup(**setup_params)
